%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Getting Normalization Right: Dealing with `Dimensional Constants' in
%Macroeconomics
%C. Cantore and P. Levine - University of Surrey and CIMS
%This software is distributed under the GNU general pubblic license.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%This program computes the steady state of the Small Open Economy RBC model 
%under re-parametrization of the CES utility function as trade balance varies. 
%It produces figures showing how the terms of trade and/or the relative income 
%change with the steady state trade balance for a given relative efficency
%of the SOE with the rest of the world (Figure 4 in the paper).
%It calls fun_NK_SOE_CES.m which solves for the steady state of the model
%under re-parametrization.

close all
clear all
clc

%function [ys,check] = NK_SOE_CES_steadystate_loop(ys,exe);

%Calibration

betah    = 0.9863; 
beta     = 0.99;
cy       = 0.6;
iy       = 0.2;
yss      = 1;
gh       = 0.025/4;
gh       = 0;
gyh      = 0.15;
csexp    = 0.23;
isexp    = 0.02;
csimp    = 0.10;
isimp    = 0.15;

xih      = 0.75; 
hch      = 0.60;
sigmah   = 3.00;  
rho_gh   = 0.85; 
rho_ah   = 0.85; 
rho_rh   = 0.90; 
rho_msh  = 0.50;
rho_uiph = 0.20;
thetaph  = 2.00;
thetash  = 0.50;
theta_tb = 0.01;
zetah    = 7.67;
thetah   = 0.28;
varrhoh  = 0.17;
lamh     = 0.2; 
lamh     = 0.0; 
alphah   = 0.77;
deltah   = 0.069;
phi_ih   = 10;
g_ih     = 1+gh;
phi_Bh   = -0.001;
w        =1;
rhoIh    = 0.5;
rhoI     = 0.5;
muh      = 1.5;
mu       = 1.5;
c        = 0.1429;
rho_r    = 0.5;
rho_pie  = 0.5;
rho_c    = 0.5;
rho_i    = 0.5;
rho_muc  = 0.5;
kB       = 1;
chiB     = -0.05;
habh     = 0.7/(1+gh);

% implied variables
Ah       = 1; 
PIE      = 1;
C        = cy*yss;
I        = iy*yss;
%RERh=1; % so MUCstar=MUC in SS
PIEh     = 1;
R        = 1/beta-1; %R-1
%Gh   = gyh*Yh;

% derived parameter or SS varaible values
Rh       = 1/(betah*(1+gh)^((1-varrhoh)*(1-sigmah)-1))-1; %Rh+-1
RRh      = Rh;
%Rh=1/betah;
Rnh      = Rh; % Rnh=Rh-1 no longer correct
MCh      = 1-1/zetah;

% zero TB uniqe SS
TBh=0;
%TBh=0.01;
%
%loop
%
for i=1:3
for j=1:201
    tb=(j-1)*0.0001;
    k=i;
tbvec(j)=tb;
%
%
%--------------------------------------------------------------------------

x0=[0 0 0 0];

[x,fval]=fsolve(@fun_NK_SOE_CES,x0,optimset('Display','off'),...
                betah, xih, hch, sigmah, zetah, varrhoh, lamh, alphah,...
                deltah, phi_ih, g_ih, phi_Bh, w, rhoIh, rhoI,...
                muh, mu, c, cy, iy, yss, csexp, isexp, gh, gyh, csimp, isimp,...
                Ah, PIE, C, I, PIEh, R, Rh, RRh, Rnh, MCh, kB, chiB, TBh, habh, tb,k);

%x=real(x);
Yh=exp(x(1));
PHh=exp(x(2));
%omega=exp(x(3))/(1+exp(x(3)));
%omegaI=exp(x(4))/(1+exp(x(4)));
wh=exp(x(3))/(1+exp(x(3)));
whvec(j)=wh;
wIh=exp(x(4))/(1+exp(x(4)));
if i==1 whvec1(j)=wIh;
end
if i==2 whvec2(j)=wIh;
end
if i==3 whvec3(j)=wIh;
end
if i==1 whvec1(j)=wIh;
end
if i==2 wIhvec2(j)=wIh;
end
if i==3 wIhvec3(j)=wIh;
end
PFh   = ((1-wh*PHh^(1-muh))/(1-wh))^(1/(1-muh)); 
Tauh  = (((1/PHh)^(1-muh)-wh)/(1-wh))^(1/(1-muh));
if i==1 Tauhvec1(j)=Tauh;
end
if i==2 Tauhvec2(j)=Tauh;
end
if i==3 Tauhvec3(j)=Tauh;
end
RERhC = (w+(1-w)*Tauh^(mu-1))^(1/(1-mu))/(1-wh+wh*Tauh^(muh-1))^(1/(1-muh));
RERhI = (w+(1-w)*Tauh^(mu-1))^(1/(1-mu))/(1-wIh+wIh*Tauh^(rhoIh-1))^(1/(1-rhoIh));
PIh   = (wIh*PHh^(1-rhoIh)+(1-wIh)*PFh^(1-rhoIh))^(1/(1-rhoIh));
Qh    = PIh; 
Kh    = ((1-alphah)*MCh*PHh*Yh)/((Rh+deltah)*Qh); % Rh-1 to Rh
Ih    = (gh+deltah)*Kh; 
C1h   = MCh*PHh*alphah*Yh; 
Lh    = (Yh/((1-c)*Kh^(1-alphah)))^(1/alphah)/Ah;
Wh    = C1h/Lh; 
omega=1-csexp/((PHh/RERhC)^(-mu)*(C)/Yh)*PHh;
omegaI=1-isexp/((PHh/(PIh*RERhI))^(-rhoI)*(I)/Yh)*PHh;
CH    = (1-omega)*(PHh/RERhC)^(-mu)*(C);
IH    = (1-omegaI)*(PHh/(PIh*RERhI))^(-rhoI)*I;
IHh   = wIh*(PHh/PIh)^(-rhoIh)*Ih;
Ch    = (Yh-gyh*Yh-IHh-CH-IH)/(wh*PHh^(-muh));
C2h   = (Ch-lamh*C1h)/(1-lamh); 
MUCh  = (1-varrhoh)*(C2h/(1-habh)-habh/(1-habh)*C2h)^((1-varrhoh)*(1-sigmah)-1)*((1-Lh)^(varrhoh*(1-sigmah)));
MUNh  = -(C2h/(1-habh)-habh/(1-habh)*C2h)^((1-varrhoh)*(1-sigmah))*varrhoh*((1-Lh)^(varrhoh*(1-sigmah)-1));

MUC          = MUCh;
RERrh        = MUC/MUCh;
RERdh        = RERhC/RERrh;
CFh          = (1-wh)*PFh^(-muh)*Ch;
CHh          = wh*PHh^(-muh)*Ch;
Gh           = gyh*Yh;
IFh          = (1-wIh)*(PFh/PIh)^(-rhoIh)*Ih;
MUChbar      = (1+Rh)/(PIEh)*MUCh;
PHWh         = MCh*PHh;
Hh           = Yh*MUCh/(1-xih*(betah*(1+gh)^((1-varrhoh)*(1-sigmah)-1)));
Jh           = Hh;
PIEHh        = 1;
PH1h         =((PIEHh^(zetah-1))*Hh);
PJ1h         = ((PIEHh^(zetah))*Jh); 
INVPIEh      = 1/PIEh;
Xh           = 1;
EUIPh        = 1;
Z1h          = phi_ih*(Xh-g_ih)*Xh*Qh*Xh^2/(1+RRh); %1+RRh
Z2h          = (PHWh*(1-alphah)*Yh/Kh+(1-deltah)*Qh);
%Z2ha         = RRh;
INVPIE       = 1/PIE;
MSh          = 1;
SXh          = phi_ih/2*(Xh-g_ih)^2;
PIEFh        = PIEHh;
Sh           = 1;
BFh          = 0;%!!!!!!!!!!!!!!!!!
PHIsbfh      = kB*(1+Sh*BFh/(Yh*PHh))^chiB;
Z4h          = (1/PIE)*(1/(EUIPh*PHIsbfh)-1);

% steady state vector for fname_steadystate.m
ys=[Ah; Ch; C1h; C2h; CFh; CH; CHh; Gh; Hh; IFh; Ih; IH; IHh;... 
      Jh; Kh; Lh; MCh; MUCh; MUNh; MSh; PHWh; Qh; Rh; RRh;... 
      SXh; Tauh; Wh; Xh; Yh; PIEFh; PIEHh; PIEh; Sh; PHh; PFh; PIh;... 
      MUChbar; PH1h; PJ1h; INVPIEh; Z1h; Z2h; MUC; C; I; PIE; R;...
      TBh; PHIsbfh; BFh; RERrh; RERdh; EUIPh; Z4h;...
      RERhC; RERhI];  %Z2ha;; omega; omegaI; wh; wIh
end
end

%Plot figures
figure
plot(tbvec,whvec1, tbvec, whvec2, tbvec, whvec3);
ylabel('Utility weight');
xlabel('Trade balance');
legend('k=1','k=2','k=3',-1);
figure
plot(tbvec,Tauhvec1, tbvec, Tauhvec2, tbvec,Tauhvec3);
ylabel('Terms of Trade');
xlabel('Trade balance');
legend('k=1','k=2','k=3',-1);
