%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Getting Normalization Right: Dealing with `Dimensional Constants' in
%Macroeconomics
%C. Cantore and P. Levine - University of Surrey and CIMS
%This software is distributed under the GNU general pubblic license.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%function used by the program twosectorsteadystate_muloop2.m

function y=fun_twosector_2(x)
global par postrec

%

mu=par(1); gy1=par(2);  gy2=par(3);  varrho=par(4); alp1=par(5); alp2=par(6); c1=par(7); c2=par(8);...
zeta1=par(9); zeta2=par(10); beta=par(11); 
g=par(12); delta=par(13); sigma=par(14); A1=par(15); A2=par(16); 
omegaC=par(17); rw=par(18); omegaY=par(19);

% x(1)=exp trans n1; x(2)=T; x(3)= exp trans of h1; x(4)=exp trans of h2
%
% Definitions: PFP=PF/P; PIP=PI/P; PFWPF=PFW/PF; PIWPI=PIW/PI  
%
n1=exp(x(1))/(1+exp(x(1)));
T=exp(x(2));
h1=exp(x(3))/(1+exp(x(3)));
h2=exp(x(4))/(1+exp(x(4)));
w=exp(x(5))/(1+exp(x(5)));


%
% P1P=P1/P; P2P=P2/P; T=P2/P1
%
P1P=1/(w+(1-w)*T^(1-mu))^(1/(1-mu));
P2P=1/(w*T^(mu-1)+(1-w))^(1/(1-mu));
n2=1-n1;
R=1.0/beta*(1+g)^(1+(1-varrho)*(sigma-1))-1;

P1PW=(1-1/zeta1)*P1P;  
P2PW=(1-1/zeta2)*P2P;  
%
KY1=P1PW*(1-alp1)/(R+delta);
KY2=P2PW*(1-alp2)/(R+delta);
Y1W=A1*(n1*h1)*KY1^((1-alp1)/alp1);
Y2W=A2*(n2*h2)*KY2^((1-alp2)/alp2);
K1=KY1*Y1W;
K2=KY2*Y2W;
I1=(delta+g)*K1;
I2=(delta+g)*K2;
Y1=(1-c1)*Y1W;
Y2=(1-c2)*Y2W;
G1=gy1*Y1;
G2=gy2*Y2;
C=(Y2-I2-G2)*P2P^(mu)/(1-w);
C1=w*(P1P)^(-mu)*C;
C2=(1-w)*(P2P)^(-mu)*C;
relY1=P1P*Y1/(P1P*Y1+P2P*Y2);
relC1=P1P*C1/(P1P*C1+P2P*C2);
%
%Reparameterize w
%
%omegaY-relY1
%
%
MUC=(1-varrho)*C^((1-varrho)*(1-sigma)-1)*(n1*(1-h1)^(varrho*(1-sigma))...
    +n2*(1-h2)^(varrho*(1-sigma)));
W1P=varrho*(C^((1-varrho)*(1-sigma)))*(1-h1)^(varrho*(1-sigma)-1)/MUC;
W2P=varrho*(C^((1-varrho)*(1-sigma)))*(1-h2)^(varrho*(1-sigma)-1)/MUC;

y=[Y1-C1-I1-G1,...
W1P-alp1*P1PW*Y1W/(n1*h1),...
W2P-alp2*P2PW*Y2W/(n2*h2),...
W1P-(1+rw)*W2P, omegaY-relY1];

%
postrec(1)=P1P;
postrec(2)=P2P;
postrec(3)=T;
postrec(4)=MUC;
postrec(5)=R;
postrec(6)=C1;
postrec(7)=C2;
postrec(8)=W1P;
postrec(9)=h1;
postrec(10)=h2;
postrec(11)=Y1W;
postrec(12)=Y2W;
postrec(13)=Y1;
postrec(14)=Y2;
postrec(15)=n1;
postrec(16)=P1PW;
postrec(17)=P2PW;
postrec(18)=K1;
postrec(19)=K2;
postrec(20)=I1;
postrec(21)=I2;
postrec(22)=C;
postrec(23)=w;
postrec(24)=relC1;