%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Getting Normalization Right: Dealing with `Dimensional Constants' in
%Macroeconomics
%C. Cantore and P. Levine - University of Surrey and CIMS
%This software is distributed under the GNU general pubblic license.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%This program computes the steady state of the one sector RBC model under
%re-parametrization of the CES production function as sigma varies. It produces figures showing
%how the great ratios are constant and how the two dimensional constants
%change when sigma is varied (Figure 1 in the paper).

close all
clear all
clc

%Calibration
beta = 0.99; 
delta = 0.025; 
rho = 0.95;  
sigma=0.1; 
sigma_c=2;
varrho=0.6030;
pi=0.6;
gy=0.2;
Y0=1;
AL0=1;
AK0=1;


%
%loop for sigma
%
for j=1:300
sigma=0.01+(j-1)*0.01;
sigmavec(j)=sigma;

%
%
%

%Steady State Relationships 
R=1/beta-1;

AL=AL0;
AK=AK0;
Y=Y0;
KY=(1-pi)/(R+delta);
K=KY*Y;
I=delta*K;
G=gy*Y;
C=Y-I-G;
alpha_k=(1-pi)*(Y/(AK*K))^((sigma-1)/sigma);
h=1/(1+C/Y*varrho/((1-varrho)*pi));
alpha_h=pi*(Y/(h*AL))^((sigma-1)/sigma);
WP=pi*Y/h;
tax=G/(WP*h);
LAMBDA=((C^(1-varrho)*(1-h)^(varrho))^(1-sigma_c)-1)/(1-sigma_c);
LAMBDAC=(C^(1-varrho)*(1-h)^(varrho))^(1-sigma_c)*(1-varrho)/C;
LAMBDAN=-(C^(1-varrho)*(1-h)^(varrho))^(1-sigma_c)*(varrho)/(1-h);
Yvec(j)=Y;
Cvec(j)=C;
Ivec(j)=I;
Gvec(j)=G;
hvec(j)=h;
WPvec(j)=WP;
CYvec(j)=C/Y;
IYvec(j)=I/Y;
GYvec(j)=G/Y;
ALvec(j)=AL;
AKvec(j)=AK;
alpkvec(j)=alpha_k;
alphvec(j)=alpha_h;
end

%Plot figures
%figure
%plot( sigmavec, Cvec, sigmavec, Ivec, sigmavec, Gvec, sigmavec, WPvec,  sigmavec, hvec, sigmavec, ALvec);
%legend('C','I','G','W','h','ZL');
%title('Steady State Endogenous Variables');
figure
plot(sigmavec, CYvec, sigmavec, IYvec, sigmavec, GYvec, sigmavec, WPvec,  sigmavec, hvec, sigmavec, ALvec);
xlabel('\sigma');
legend('C/Y','I/Y','G/Y','W','h','ZL');
title('Steady State Endogenous Variables');
figure
subplot(3,1,1);
plot( sigmavec, alpkvec);
title('\alpha_k');
xlabel('\sigma');
subplot(3,1,2);
plot( sigmavec(20:300), alpkvec(20:300));
xlabel('\sigma');
subplot(3,1,3);
plot( sigmavec(40:300), alpkvec(40:300));
xlabel('\sigma');
figure
plot( sigmavec, alphvec);
xlabel('\sigma');
title('\alpha_h');