%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Getting Normalization Right: Dealing with `Dimensional Constants' in
%Macroeconomics
%C. Cantore and P. Levine - University of Surrey and CIMS
%This software is distributed under the GNU general pubblic license.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%This program computes the steady state of the two sector RBC model under
%parametrization 2 of the CES utility function as mu varies. It produces 
%figures showing how the parameter w the relative price in sector 2 P2/P, 
%the steady state of employment share n1 and the output share (p1 Y1)/(P Y) 
%as mu varies (Figure 3 in the paper).
%It calls fun_twosector2.m which solves for the steady state of the model
%under parametrization 2.

close all
clear all
clc

global par postrec

%Calibration

mu=1.5;
gy1=0.2;
gy2=0.2;
varrho=0.6073;
alp1=0.5000;
alp2=0.8000;
c1=0.1429;
c2=0.1429;
%
%Perfect Competition Case Zeta -> infinity
%
zeta1=10000000;
zeta2=zeta1;
c1=1/zeta1;
c2=c1;
beta=0.9871;
g=0;
delta=0.0250;
sigma=2.0;
A1ss=1;
A2ss=1;
omegaC=0.75; %=P1C1/PC
omegaY=0.75; %=P1Y1/PY
rw=0.0;
par=[mu gy1 gy2 varrho alp1 alp2 c1 c2 zeta1 zeta2 beta g delta sigma A1ss A2ss omegaC rw omegaY];
 %initial values
  x0=[0.0 0.0 0.0 0.0 0.0];
y=fun_twosector_2(x0);


%
%loop
%
for j=1:200
mu=0.01+(j-1)*0.01;
muvec(j)=mu;
par(1)=mu;
%
%
%
[x,fval] =fsolve(@fun_twosector_2,x0,optimset('Display','off'));
x0=x;
P1P=postrec(1);
P2P=postrec(2);
T=postrec(3);
MUC=postrec(4);
R=postrec(5);
C1=postrec(6);
C2=postrec(7);
W1P=postrec(8);
h1=postrec(9);
h2=postrec(10);
Y1W=postrec(11);
Y2W=postrec(12);
Y1=postrec(13);
Y2=postrec(14);
n1=postrec(15);
P1PW=postrec(16);
P2PW=postrec(17);
K1=postrec(18);
K2=postrec(19);
I1=postrec(20);
I2=postrec(21);
C=postrec(22);
w=postrec(23); 
relC1=postrec(24);
%
%
%
n1vec(j)=n1;
wvec(j)=w; 
P2Pvec(j)=P2P;
relC1vec(j)=relC1;
end
P2Pvec(100)=(P2Pvec(99)+P2Pvec(101))/2.0;
relC1vec(100)=(relC1vec(99)+relC1vec(101))/2.0;

%Plot figures
figure
plot(muvec, wvec, muvec, P2Pvec);
xlabel('\mu');
legend('w','P2/P',-1)
figure
plot(muvec,n1vec, muvec, relC1vec)
xlabel('\mu');
legend('n1','P1 C1/P C',-1)